[cfe-commits] r172595 - in /cfe/trunk: include/clang/StaticAnalyzer/Core/PathSensitive/ProgramState.h lib/StaticAnalyzer/Checkers/CStringChecker.cpp lib/StaticAnalyzer/Checkers/RetainCountChecker.cpp

Anna Zaks ganna at apple.com
Tue Jan 15 17:35:54 PST 2013


Author: zaks
Date: Tue Jan 15 19:35:54 2013
New Revision: 172595

URL: http://llvm.org/viewvc/llvm-project?rev=172595&view=rev
Log:
[analyzer] Refactor: parameter rename.

Modified:
    cfe/trunk/include/clang/StaticAnalyzer/Core/PathSensitive/ProgramState.h
    cfe/trunk/lib/StaticAnalyzer/Checkers/CStringChecker.cpp
    cfe/trunk/lib/StaticAnalyzer/Checkers/RetainCountChecker.cpp

Modified: cfe/trunk/include/clang/StaticAnalyzer/Core/PathSensitive/ProgramState.h
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/include/clang/StaticAnalyzer/Core/PathSensitive/ProgramState.h?rev=172595&r1=172594&r2=172595&view=diff
==============================================================================
--- cfe/trunk/lib/StaticAnalyzer/Checkers/CStringChecker.cpp (original)
+++ cfe/trunk/lib/StaticAnalyzer/Checkers/CStringChecker.cpp Tue Jan 15 19:35:54 2013
@@ -817,7 +817,7 @@
     // Invalidate this region.
     const LocationContext *LCtx = C.getPredecessor()->getLocationContext();
     return state->invalidateRegions(R, E, C.blockCount(), LCtx,
-                                    /*CausedByPointerEscape*/ false);
+                                    /*CausesPointerEscape*/ false);
   }
 
   // If we have a non-region value by chance, just remove the binding.

Modified: cfe/trunk/lib/StaticAnalyzer/Checkers/RetainCountChecker.cpp
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/lib/StaticAnalyzer/Checkers/RetainCountChecker.cpp?rev=172595&r1=172594&r2=172595&view=diff
==============================================================================
--- cfe/trunk/lib/StaticAnalyzer/Checkers/RetainCountChecker.cpp (original)
+++ cfe/trunk/lib/StaticAnalyzer/Checkers/RetainCountChecker.cpp Tue Jan 15 19:35:54 2013
@@ -3175,7 +3175,7 @@
 
     // Invalidate the argument region.
     state = state->invalidateRegions(ArgRegion, CE, C.blockCount(), LCtx,
-                                     /*CausedByPointerEscape*/ false);
+                                     /*CausesPointerEscape*/ false);
 
     // Restore the refcount status of the argument.
     if (Binding)





More information about the cfe-commits mailing list
--- cfe/trunk/include/clang/StaticAnalyzer/Core/PathSensitive/ProgramState.h (original)
+++ cfe/trunk/include/clang/StaticAnalyzer/Core/PathSensitive/ProgramState.h Tue Jan 15 19:35:54 2013
@@ -222,8 +222,8 @@
   /// \param E the expression that caused the invalidation.
   /// \param BlockCount The number of times the current basic block has been
   //         visited.
   /// \param CausedByPointerEscape the flag is set to true when
   ///        the invalidation is due to escape of a symbol (representing a
   ///        pointer). For example, due to it being passed as an argument in a
   ///        call.
   /// \param IS the set of invalidated symbols.
@@ -232,7 +232,7 @@
   ProgramStateRef invalidateRegions(ArrayRef<const MemRegion *> Regions,
                                     const Expr *E, unsigned BlockCount,
                                     const LocationContext *LCtx,
-                                    bool CausedByPointerEscape,
+                                    bool CausesPointerEscape,
                                     InvalidatedSymbols *IS = 0,
                                     const CallEvent *Call = 0) const;
 
@@ -222,8 +222,8 @@
   /// \param BlockCount The number of times the current basic block has been
   //         visited.
-  /// \param CausedByPointerEscape the flag is set to true when
-  ///        the invalidation is due to escape of a symbol (representing a
+  /// \param CausesPointerEscape the flag is set to true when
+  ///        the invalidation entails escape of a symbol (representing a
   ///        pointer). For example, due to it being passed as an argument in a
   ///        call.

Modified: cfe/trunk/lib/StaticAnalyzer/Checkers/CStringChecker.cpp
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/lib/StaticAnalyzer/Checkers/CStringChecker.cpp?rev=172595&r1=172594&r2=172595&view=diff
==============================================================================